import datetime
import io
import json
import logging
import pathlib
import random
import sys

import appdirs
import diskcache
import humanfriendly
import requests

cache_path = pathlib.Path(appdirs.user_cache_dir(appname="clinepunk"))
url = (
    "https://raw.githubusercontent.com/dwyl/english-words/master/words_dictionary.json"
)


def refresh_cache():
    r = requests.get(url)

    if r.status_code == 200:
        dct = r.json()
        js = json.dumps(dct, indent=2).encode("utf-8")
        return js
    return ""


def get_words(count=1):
    js = ""
    with diskcache.Cache(cache_path) as reference:
        result = reference.get("clinepunk.words")
        if not result:
            logging.debug("setting cache")
            js = refresh_cache()
            reference.set(
                "clinepunk.words",
                io.BytesIO(js),
                expire=datetime.timedelta(days=365 * 2).total_seconds(),
            )
        else:
            logging.debug("cache is still fresh, using it")
            reader = result
            js = reader.read().decode()

    words = json.loads(js)
    words = words.keys()
    words = list(filter(lambda x: len(x) <= 5, words))

    logging.debug(f"cache path is {cache_path}")
    logging.debug(f"cache has {len(words):,d} words")
    logging.debug(
        f"cache has size {humanfriendly.format_size(cache_path.stat().st_size, binary=True)}"
    )

    sample = random.sample(words, count)
    logging.debug(f"sample words is {sample}")

    return sample


def main():
    logging.basicConfig(
        level=logging.DEBUG,
        format="{%(filename)s:%(lineno)d} %(levelname)s - %(message)s",
        handlers=[
            logging.FileHandler(f"{pathlib.Path(__file__).stem}.log"),
            logging.StreamHandler(sys.stdout),
        ],
    )

    words = get_words(count=2)
    out = "".join(words)
    print(out)


if __name__ == "__main__":
    main()



#!/usr/bin/env python

"""The setup script."""

from setuptools import find_packages, setup

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()

requirements = [
    "Click>=7.0",
]

test_requirements = [
    "pytest>=3",
]

setup(
    author="Taylor Monacelli",
    author_email="taylormonacelli@gmail.com",
    python_requires=">=3.6",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
    ],
    description="Python Boilerplate contains all the boilerplate you need to create a Python package.",
    entry_points={
        "console_scripts": [
            "clinepunk=clinepunk.cli:main",
        ],
    },
    install_requires=requirements,
    license="MIT license",
    long_description=readme + "\n\n" + history,
    include_package_data=True,
    keywords="clinepunk",
    name="clinepunk",
    packages=find_packages(include=["clinepunk", "clinepunk.*"]),
    test_suite="tests",
    tests_require=test_requirements,
    url="https://github.com/TaylorMonacelli/clinepunk",
    version="0.1.1",
    zip_safe=False,
)
